.. SPDX-FileCopyrightText: 2024-2025 Anna <cyber@sysrq.in>
.. SPDX-License-Identifier: CC0-1.0

repology\_client
================

.. automodule:: repology_client

   .. rubric:: High-level Functions

   .. autofunction:: get_packages
   .. autofunction:: get_problems
   .. autofunction:: get_projects
   .. autofunction:: resolve_package

   .. rubric:: Low-level Functions

   .. autofunction:: api
